@@ -1,7 +1,7 @@
 
 /*
  * XKOBO, a video-oriented game
- * Copyright (C) 1995  Akira Higuchi
+ * Copyright (C) 1995,1996  Akira Higuchi
  *     a-higuti@math.hokudai.ac.jp
  * 
  * This program is free software; you can redistribute it and/or modify it
@@ -20,6 +20,10 @@
  * 
  */
 
+#ifndef XKOBO_H_FILE
+#define XKOBO_H_FILE
+
 int load_block(char *file_name, void *t, int len);
 int save_block(char *file_name, void *t, int len);
 
+#endif // XKOBO_H_FILE
