@@ -1,7 +1,7 @@
 
 /*
  * XKOBO, a video-oriented game
- * Copyright (C) 1995  Akira Higuchi
+ * Copyright (C) 1995,1996  Akira Higuchi
  *     a-higuti@math.hokudai.ac.jp
  * 
  * This program is free software; you can redistribute it and/or modify it
@@ -20,17 +20,15 @@
  * 
  */
 
-#ifndef _RADAR
-#define _RADAR
+#ifndef XKOBO_H_RADAR
+#define XKOBO_H_RADAR
 
-#define RADAR_FOREGROUND0  253
-#define RADAR_FOREGROUND1  240
-#define RADAR_FOREGROUND2  126
-#define RADAR_BACKGROUND     8
 
 class _radar{
     static int sx, sy;
     static int mx_old, my_old;
+    static int pixel_f0, pixel_f1, pixel_f2, pixel_b;
+    static void set_a_pixel(int x, int y);
   public:
     static void prepare();
     static void erase(int x, int y);
@@ -39,4 +37,4 @@ class _radar{
 
 extern _radar radar;
 
-#endif // _RADAR
+#endif // XKOBO_H_RADAR
