@@ -1,7 +1,7 @@
 
 /*
  * XKOBO, a video-oriented game
- * Copyright (C) 1995  Akira Higuchi
+ * Copyright (C) 1995,1996  Akira Higuchi
  *     a-higuti@math.hokudai.ac.jp
  * 
  * This program is free software; you can redistribute it and/or modify it
@@ -20,31 +20,42 @@
  * 
  */
 
-#ifndef _RANDOM
-#define _RANDOM
+#ifndef XKOBO_H_RANDOM
+#define XKOBO_H_RANDOM
 
-class _random{
+extern "C"{
+#include <time.h>
+}
+
+class _rand_num{
     static unsigned long seed;
   public:
-    _random();
+    static inline void init();
     static inline unsigned long get();
     static inline unsigned long get(unsigned int bit);
 };
 
-inline unsigned long _random::get()
+inline void _rand_num::init()
+{
+    seed = (unsigned long)time((time_t *)0);
+}
+
+inline unsigned long _rand_num::get()
 {
     seed *= 1566083941UL;
     seed++;
+    seed &= 0xffffffffUL;
     return seed;
 }
 
-inline unsigned long _random::get(unsigned int bit)
+inline unsigned long _rand_num::get(unsigned int bit)
 {
     seed *= 1566083941UL;
     seed++;
+    seed &= 0xffffffffUL;
     return (seed >> (32 - bit));
 }
 
-extern _random random;
+extern _rand_num rand_num;
 
-#endif // _RANDOM
+#endif // XKOBO_H_RANDOM
