@@ -1,7 +1,7 @@
 
 /*
  * XKOBO, a video-oriented game
- * Copyright (C) 1995  Akira Higuchi
+ * Copyright (C) 1995,1996  Akira Higuchi
  *     a-higuti@math.hokudai.ac.jp
  * 
  * This program is free software; you can redistribute it and/or modify it
@@ -20,8 +20,8 @@
  * 
  */
 
-#ifndef _SCREEN
-#define _SCREEN
+#ifndef XKOBO_H_SCREEN
+#define XKOBO_H_SCREEN
 
 #include "map.h"
 
@@ -33,6 +33,7 @@ class _screen{
     static void title();
     static void copy_a_chip(int n, int posx, int posy);
     static int scene_max;
+    static int pixel_f0, pixel_f1, pixel_f2, pixel_s[8];
   public:
     static void init();
     static void init_scene(int sc);
@@ -44,4 +45,4 @@ class _screen{
 
 extern _screen screen;
 
-#endif // _SCREEN
+#endif // XKOBO_H_SCREEN
