@@ -1,7 +1,7 @@
 
 /*
  * XKOBO, a video-oriented game
- * Copyright (C) 1995  Akira Higuchi
+ * Copyright (C) 1995,1996  Akira Higuchi
  *     a-higuti@math.hokudai.ac.jp
  * 
  * This program is free software; you can redistribute it and/or modify it
@@ -20,8 +20,8 @@
  * 
  */
 
-#ifndef _TOWNSTIFF
-#define _TOWNSTIFF
+#ifndef XKOBO_H_TIFF
+#define XKOBO_H_TIFF
 
 #include "file.h"
 #include "xlchip.h"
@@ -33,5 +33,4 @@
 int load_tiff(char *file_name, win_cmap& wcm, win_chip& wch);
 int link_tiff(unsigned char *data, win_cmap& wcm, win_chip& wch);
 
-#endif // _TOWNSTIFF
-
+#endif // XKOBO_H_TIFF
