@@ -23,7 +23,7 @@
 #ifndef XKOBO_H_VERSION
 #define XKOBO_H_VERSION
 
-#define XKOBO_VERSION     "Version 1.9"
-#define XKOBO_DATE        "Thu Apr  4 09:49:01 JST 1996"
+#define XKOBO_VERSION     "Version 1.11"
+#define XKOBO_DATE        "Fri Jan 10 11:17:50 JST 1997"
 
 #endif // XKOBO_H_VERSION
