@@ -1,7 +1,7 @@
 
 /*
  * XKOBO, a video-oriented game
- * Copyright (C) 1995  Akira Higuchi
+ * Copyright (C) 1995,1996  Akira Higuchi
  *     a-higuti@math.hokudai.ac.jp
  * 
  * This program is free software; you can redistribute it and/or modify it
@@ -20,8 +20,8 @@
  * 
  */
 
-#ifndef _XKOBO
-#define _XKOBO
+#ifndef XKOBO_H_XKOBO
+#define XKOBO_H_XKOBO
 
 #include "xlchip.h"
 #include "xlcmap.h"
@@ -30,6 +30,11 @@ extern win_chip wchip;
 extern win_cmap wbase;
 extern win_backing wradar;
 extern win_backing wscore;
-extern unsigned char spdata[];
+extern int scale_log2;
+extern int mouse_x, mouse_y;
+extern int cheat_mode;
+extern "C" {
+    extern unsigned char spdata[];
+}
 
-#endif // _XKOBO
+#endif // XKOBO_H_XKOBO
