@@ -40,7 +40,6 @@ class win_backing : public win{
     long fgcolor;
     long bgcolor;
     Pixmap p;
-    Font font;
     
   public:
     win_backing();
@@ -52,7 +51,7 @@ class win_backing : public win{
     virtual void expose_backing();                 /* from eventroop() */
     void foreground(int c);
     void background(int c);
-    void load_font(char *s);
+    void font(char *s);
     void warp_pointer(int x, int y);
     inline void point_back(int x,int y){
         XDrawPoint(disp,p,gc,x,y);}
