@@ -32,12 +32,6 @@ extern "C"{
 #include <string.h>
 }
 
-#ifdef  DEBUG_XRES
-#define DBGP(x) printf("%12lu  (" #x ")\n", (unsigned long)(x))
-#else
-#define DBGP(x) (x)
-#endif
-
 Bool event_predicate(Display *, XEvent *, char *);
 
 class win{
